==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/zh-hant/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "現在",
	"field-weekday": "週天",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-GyMMMEd": "G y 年 M 月 d 日 E",
	"dateFormatItem-MMMEd": "M 月 d 日E",
	"field-tue-relative+-1": "上週二",
	"dateFormat-long": "G y年M月d日",
	"field-fri-relative+-1": "上週五",
	"field-wed-relative+-1": "上週三",
	"dateFormatItem-yyyyQQQ": "G y 年 QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "G y 年 M 月 d 日 EEEE",
	"dateFormatItem-yyyyMEd": "G y/M/d (E)",
	"field-thu-relative+-1": "上週四",
	"dateFormatItem-Md": "M/d",
	"field-era": "年代",
	"field-year": "年",
	"field-hour": "小時",
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本週四",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "G y 年 M 月 d 日",
	"field-day-relative+2": "後天",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-H": "H時",
	"dateFormatItem-Gy": "G y 年",
	"dateFormatItem-yyyyMMMEd": "G y 年 M 月 d 日E",
	"dateFormatItem-M": "M月",
	"dateFormatItem-yyyyMMM": "G y 年 M 月",
	"dateFormatItem-yyyyMMMd": "G y 年 M 月 d 日",
	"field-sun-relative+0": "本週日",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "下週日",
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M/d (E)",
	"dateTimeFormat-full": "{1}{0}",
	"field-fri-relative+0": "本週五",
	"field-fri-relative+1": "下週五",
	"field-day": "日",
	"field-zone": "時區",
	"dateFormatItem-y": "G y 年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-month": "月",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"dateFormat-short": "G y/M/d",
	"field-second": "秒",
	"field-sat-relative+-1": "上週六",
	"field-sun-relative+-1": "上週日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"field-week": "週",
	"dateFormat-medium": "G y年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"dateFormatItem-yyyyM": "G y/M",
	"field-year-relative+1": "明年",
	"dateFormatItem-yyyyQQQQ": "G y 年 QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-yyyy": "G y 年",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);

==> dojo_1.13.0+dfsg1.orig.tar.gz: dojo-release-1.13.0-src/dojo/cldr/nls/zh-hant/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "現在",
	"field-weekday": "週天",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-GyMMMEd": "G y年M月d日 E",
	"dateFormatItem-MMMEd": "M月d日 E",
	"field-tue-relative+-1": "上週二",
	"dateFormat-long": "G y年M月d日",
	"field-fri-relative+-1": "上週五",
	"field-wed-relative+-1": "上週三",
	"dateFormatItem-yyyyQQQ": "G y年QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "G y年M月d日 EEEE",
	"dateFormatItem-yyyyMEd": "G y/M/d（E）",
	"field-thu-relative+-1": "上週四",
	"dateFormatItem-Md": "M/d",
	"field-era": "年代",
	"field-year": "年",
	"field-hour": "小時",
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本週四",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "G y年M月d日",
	"field-day-relative+2": "後天",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-H": "H時",
	"dateFormatItem-Gy": "G y年",
	"dateFormatItem-yyyyMMMEd": "G y年M月d日 E",
	"dateFormatItem-M": "M月",
	"dateFormatItem-yyyyMMM": "G y年M月",
	"dateFormatItem-yyyyMMMd": "G y年M月d日",
	"field-sun-relative+0": "本週日",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "下週日",
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M/d（E）",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "本週五",
	"field-fri-relative+1": "下週五",
	"field-day": "日",
	"field-zone": "時區",
	"dateFormatItem-y": "G y年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-month": "月",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"dateFormat-short": "G y/M/d",
	"field-second": "秒",
	"field-sat-relative+-1": "上週六",
	"field-sun-relative+-1": "上週日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"field-week": "週",
	"dateFormat-medium": "G y年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"dateFormatItem-yyyyM": "G y/M",
	"field-year-relative+1": "明年",
	"dateFormatItem-yyyyQQQQ": "G y年QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "G y年M月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-yyyy": "G y年",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);
